Index: branches/2016/dev_CNRS_2016/NEMOGCM/SETTE/sette.sh
===================================================================
--- branches/2016/dev_CNRS_2016/NEMOGCM/SETTE/sette.sh	(revision 7378)
+++ branches/2016/dev_CNRS_2016/NEMOGCM/SETTE/sette.sh	(revision 7384)
@@ -144,5 +144,5 @@
 #                     17 & 18 
 
-for config in 14 15  16 17 18
+for config in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18
 
 do
@@ -913,10 +913,10 @@
 
 
 # TESTS FOR ORCA2_SAS_LIM CONFIGURATION
 if [ ${config} -eq 11 ] ;  then
     ## Restartability tests for SAS
     export TEST_NAME="LONG"
     cd ${CONFIG_DIR}
-    . ./makenemo -m ${CMP_NAM} -n SAS_LONG -r ORCA2_SAS_LIM -j 8 add_key "key_mpp_rep" del_key ${DEL_KEYS}
+    . ./makenemo -m ${CMP_NAM} -n SAS_LONG -r ORCA2_SAS_LIM3 -j 8 add_key "key_mpp_rep" del_key ${DEL_KEYS}
     cd ${SETTE_DIR}
     . ./param.cfg
@@ -1221,4 +1221,6 @@
     set_namelist namelist_cfg ln_read_cfg .true.
     set_namelist namelist_cfg ln_linssh .true.
+    set_namelist namelist_cfg ln_hpg_sco .false.
+    set_namelist namelist_cfg ln_hpg_zps .true. 
     set_namelist namelist_cfg nn_fwb 0
     set_namelist namelist_cfg jpni 1
@@ -1231,4 +1233,6 @@
     set_namelist 1_namelist_cfg ln_read_cfg .true.
     set_namelist 1_namelist_cfg ln_linssh .true.
+    set_namelist 1_namelist_cfg ln_hpg_sco .false.
+    set_namelist 1_namelist_cfg ln_hpg_zps .true. 
     if [ ${USING_MPMD} == "yes" ] ; then
        set_xio_using_server iodef.xml true
@@ -1263,4 +1267,6 @@
     set_namelist namelist_cfg ln_read_cfg .true.
     set_namelist namelist_cfg ln_linssh .true.
+    set_namelist namelist_cfg ln_hpg_sco .false.
+    set_namelist namelist_cfg ln_hpg_zps .true. 
     set_namelist namelist_cfg nn_fwb 0
     set_namelist namelist_cfg jpni 2
@@ -1298,4 +1304,6 @@
     set_namelist namelist_cfg ln_read_cfg .true.
     set_namelist namelist_cfg ln_linssh .true.
+    set_namelist namelist_cfg ln_hpg_sco .false.
+    set_namelist namelist_cfg ln_hpg_zps .true. 
     set_namelist namelist_cfg nn_fwb 0
     set_namelist namelist_cfg jpni 2
@@ -1335,4 +1343,6 @@
     set_namelist namelist_cfg ln_read_cfg .true.
     set_namelist namelist_cfg ln_linssh .true.
+    set_namelist namelist_cfg ln_hpg_sco .false.
+    set_namelist namelist_cfg ln_hpg_zps .true. 
     set_namelist namelist_cfg nn_fwb 0
     set_namelist namelist_cfg jpni 2
@@ -1347,4 +1357,6 @@
     set_namelist 1_namelist_cfg ln_read_cfg .true.
     set_namelist 1_namelist_cfg ln_linssh .true.
+    set_namelist 1_namelist_cfg ln_hpg_sco .false.
+    set_namelist 1_namelist_cfg ln_hpg_zps .true. 
 #
     if [ ${USING_MPMD} == "yes" ] ; then
@@ -1369,4 +1381,6 @@
     set_namelist namelist_cfg ln_read_cfg .true.
     set_namelist namelist_cfg ln_linssh .true.
+    set_namelist namelist_cfg ln_hpg_sco .false.
+    set_namelist namelist_cfg ln_hpg_zps .true. 
     set_namelist namelist_cfg nn_fwb 0
     set_namelist namelist_cfg jpni 2
@@ -1384,4 +1398,6 @@
     set_namelist 1_namelist_cfg ln_read_cfg .true.
     set_namelist 1_namelist_cfg ln_linssh .false.
+    set_namelist 1_namelist_cfg ln_hpg_sco .false.
+    set_namelist 1_namelist_cfg ln_hpg_zps .true. 
     set_namelist namelist_cfg cn_ocerst_in \"O2LP_LONG_00000075_restart\"
     set_namelist namelist_ice_cfg cn_icerst_in \"O2LP_LONG_00000075_restart_ice\"
@@ -1426,4 +1442,6 @@
     set_namelist namelist_cfg ln_read_cfg .true.
     set_namelist namelist_cfg ln_linssh .true.
+    set_namelist namelist_cfg ln_hpg_sco .false.
+    set_namelist namelist_cfg ln_hpg_zps .true. 
     set_namelist namelist_cfg nn_fwb 0
     set_namelist namelist_cfg jpni 4
@@ -1436,4 +1454,6 @@
     set_namelist 1_namelist_cfg ln_read_cfg .true.
     set_namelist 1_namelist_cfg ln_linssh .true.
+    set_namelist 1_namelist_cfg ln_hpg_sco .false.
+    set_namelist 1_namelist_cfg ln_hpg_zps .true. 
 
     if [ ${USING_MPMD} == "yes" ] ; then
@@ -1460,4 +1480,6 @@
     set_namelist namelist_cfg ln_read_cfg .true.
     set_namelist namelist_cfg ln_linssh .true.
+    set_namelist namelist_cfg ln_hpg_sco .false.
+    set_namelist namelist_cfg ln_hpg_zps .true. 
     set_namelist namelist_cfg nn_fwb 0
     set_namelist namelist_cfg jpni 2
@@ -1470,4 +1492,6 @@
     set_namelist 1_namelist_cfg ln_read_cfg .true.
     set_namelist 1_namelist_cfg ln_linssh .true.
+    set_namelist 1_namelist_cfg ln_hpg_sco .false.
+    set_namelist 1_namelist_cfg ln_hpg_zps .true. 
 
     if [ ${USING_MPMD} == "yes" ] ; then
@@ -913,10 +913,10 @@
 
 
-# TESTS FOR ORCA2_SAS_LIM CONFIGURATION
+# TESTS FOR ORCA2_SAS_LIM3 CONFIGURATION
 if [ ${config} -eq 11 ] ;  then
     ## Restartability tests for SAS
